/*
 * Java-Gnome Bindings Library
 *
 * Copyright 2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

#include <jni.h>
#include <sys/types.h>
#include <gtk/gtk.h>
#include "jg_jnu.h"

#ifdef __cplusplus
extern "C" 
{
#endif

typedef struct{
	JNIEnv *env;
	jobject filter;
	jmethodID methodID;
} JGFilterRef;

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_new
 * Signature: (Lorg/gnu/glib/Handle;Lorg/gnu/glib/Handle;)Lorg/gnu/glib/Handle
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1new(JNIEnv *env, jclass class, jobject model, jobject root) {
    GtkTreeModel *model_g = 
        (GtkTreeModel*)getPointerFromHandle(env, model);
    GtkTreePath *root_g = 
        (GtkTreePath*)getPointerFromHandle(env, root);

    return getHandleFromPointer(env, gtk_tree_model_filter_new( model_g, root_g ));
}

gboolean static treeModelFilterVisibleFunc( GtkTreeModel *model, 
                                            GtkTreeIter *iter, 
                                            gpointer data ) {
	JGFilterRef *ref = (JGFilterRef*) data;
	return (* ref->env)->CallBooleanMethod(ref->env, 
                                               ref->filter, 
                                               ref->methodID,
                                               getHandleFromPointer(ref->env,
                                                                    model),
                                               getHandleFromPointer(ref->env,
                                                                    iter) );
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_set_visible_func
 * Signature: (Lorg/gnu/glib/Handle;Ljava/lang/String;)V
 */
JNIEXPORT void JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1set_1visible_1func(JNIEnv *env, jclass class, jobject handle, jobject ftr, jstring func) {
    JGFilterRef *ref = g_new( JGFilterRef, 1 );
    ref->env = env;
    ref->filter = (* env)->NewGlobalRef(env, ftr);

    const char *funcname = (*env)->GetStringUTFChars(env, func, NULL);
    // Get method id for the callback method name.
    ref->methodID = 
        (*env)->GetMethodID(env, 
                            (*env)->GetObjectClass(env, ref->filter), 
                            funcname, "(Lorg/gnu/glib/Handle;Lorg/gnu/glib/Handle;)Z" );
    if ( ref->methodID == NULL ) {
        (*env)->ReleaseStringUTFChars(env, func, funcname);
        g_free( ref );
        // Error!  Throw exception!
        return;
    }
    (*env)->ReleaseStringUTFChars(env, func, funcname);

    gtk_tree_model_filter_set_visible_func((GtkTreeModelFilter*)getPointerFromHandle(env,handle), treeModelFilterVisibleFunc, ref, NULL);
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_set_visible_column
 * Signature: (Lorg/gnu/glib/Handle;I)V
 */
JNIEXPORT void JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1set_1visible_1column(JNIEnv *env, jclass class, jobject filter, jint column) {
    GtkTreeModelFilter *filter_g = 
        (GtkTreeModelFilter*)getPointerFromHandle(env, filter);
    gtk_tree_model_filter_set_visible_column( filter_g, (gint)column );
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_get_model
 * Signature: (Lorg/gnu/glib/Handle;)Lorg/gnu/glib/Handle
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1get_1model(JNIEnv *env, jclass class, jobject handle) {
    GtkTreeModelFilter *handle_g = 
        (GtkTreeModelFilter*)getPointerFromHandle(env, handle);
    return getHandleFromPointer(env, gtk_tree_model_filter_get_model( handle_g ));
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_refilter
 * Signature: (Lorg/gnu/glib/Handle;)V
 */
JNIEXPORT void JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1refilter(JNIEnv *env, jclass class, jobject filter) {
    GtkTreeModelFilter *filter_g = 
        (GtkTreeModelFilter *)getPointerFromHandle(env, filter);
    gtk_tree_model_filter_refilter( filter_g );
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_clear_cache
 * Signature: (Lorg/gnu/glib/Handle;)V
 */
JNIEXPORT void JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1clear_1cache(JNIEnv *env, jclass class, jobject filter) {
    GtkTreeModelFilter *filter_g = 
        (GtkTreeModelFilter *)getPointerFromHandle(env, filter);
    gtk_tree_model_filter_clear_cache( filter_g );
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_convert_child_path_to_path
 * Signature: (Lorg/gnu/glib/Handle;Lorg/gnu/glib/Handle;)Lorg/gnu/glib/Handle
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1convert_1child_1path_1to_1path(JNIEnv *env, jclass class, jobject filter, jobject child_path) {
    GtkTreeModelFilter *filter_g = 
        (GtkTreeModelFilter *)getPointerFromHandle(env, filter);
    GtkTreePath *child_path_g = 
        (GtkTreePath *)getPointerFromHandle(env, child_path);
    return getHandleFromPointer(env, gtk_tree_model_filter_convert_child_path_to_path( filter_g, child_path_g ));
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_convert_path_to_child_path
 * Signature: (Lorg/gnu/glib/Handle;Lorg/gnu/glib/Handle;)Lorg/gnu/glib/Handle
 */
JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1convert_1path_1to_1child_1path(JNIEnv *env, jclass class, jobject filter, jobject filter_path) {
    GtkTreeModelFilter *filter_g = 
        (GtkTreeModelFilter *)getPointerFromHandle(env, filter);
    GtkTreePath *path_g = 
        (GtkTreePath *)getPointerFromHandle(env, filter_path);
    return getHandleFromPointer(env, gtk_tree_model_filter_convert_path_to_child_path( filter_g, path_g ));
}

/*
 * Class:     org_gnu_gtk_TreeModelFilter
 * Method:    gtk_tree_model_filter_get_type
 * Signature: ()I
 */
JNIEXPORT jint JNICALL Java_org_gnu_gtk_TreeModelFilter_gtk_1tree_1model_1filter_1get_1type(JNIEnv *env, jclass cls) {
    return gtk_tree_model_filter_get_type();
}

#ifdef __cplusplus
}
#endif
